=======
Credits
=======

Development Lead
----------------

* Brian May <brian@linuxpenguins.xyz>

Contributors
------------

Most of it was originally taken from the
`Meghan Clarkk lifxlan package <https://github.com/mclarkk/lifxlan>`_
and adapted to Python 3 (and asyncio obviously)

This is a fork from
`François Wautier's package <https://github.com/frawau/aiolifx>`_.
It uses coroutines as opposed to callbacks. If you prefer callbacks,
please see his implementation instead. This was forked from version 0.5.0.
